#
# spec file for package rpmrebuild
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rpmrebuild
Version:        2.14
Release:        1.1
Summary:        A tool to build a rpm file from the rpm database
License:        GPL-2.0-or-later
Group:          System/Packages
URL:            http://rpmrebuild.sourceforge.net
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
Patch1:         gpl-license.patch
Patch2:         gpl-COPYRIGHT-address.patch
Patch3:         rpmrebuild-fix-bashisms.patch
Requires:       bash
Requires:       coreutils
Requires:       cpio
Requires:       rpm-build
Requires:       sed
BuildArch:      noarch

%description
rpmrebuild allows to build an rpm file from an installed rpm, or from
another rpm file, with or without changes (batch or interactive). It
can be extended by a plugin system. A typical use is to easy repackage
a software after some configuration's change.

%prep
%setup -q -c
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
make %{?_smp_mflags}
# Remove shebang on script that are sourced and not executed
find . -iname "*.src" -exec sed -i 's,^#!/bin/bash,,g' {} \;

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} 
mv %{buildroot}%{_mandir}/fr_FR.UTF-8/ %{buildroot}%{_mandir}/fr
rm -rf %{buildroot}%{_mandir}/fr_FR/
# chmod 0755 %%{buildroot}%%{_libexecdir}/rpmrebuild/*.sh

%files
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS Changelog COPYRIGHT News README Todo
%{_bindir}/rpmrebuild
%{_libexecdir}/rpmrebuild
%{_mandir}/fr/man1/*
%{_mandir}/man1/*

%changelog
* Fri Nov  2 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.14
  + add list of optional tags, to allow rpmrebuild work with old
    rpm versions
  + add dependency on setarch
  + add debug code (calls on functions)
  + use local variables to avoid conflicts
  + rewrite html target in Makefile
  + suppress VERSION (use Version)
  + add comments in rpmrebuild_rpmqf.src to avoid bad syntax after
    GenRpmQf
  + test if awk support non-posix lshift (qf_spec_requires_raw)
  + workaround for redhat 6.x / rpm 3.x, merci Francesco
* Fri Sep 14 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.13
  + can handle recommends / supplements rpm tags
  + previous 2.12-1
  - apply patch on requires from Bruce Jerrick : Handle
    Requires(pre,post,preun,postun)
  - add new requires syntax with if ( redhat-rpm-config )
  + previous 2.11-3
  - Made minor grammatical fixes to English language translations
    (patch from beroset)
  + previous 2.11-2
  - fix bad day of week in changelog (rpmbuild warning)
  - add dependency to rpm-build package instead rpmbuild binary
- Packaging:
  + spec-cleanup minimal (date,%%licence)
  + fix executable bit in %%libexec/rpmrebuild
* Sat Sep 16 2017 bruno@ioda-net.ch
- New release of source code (2.11) release -2
  + fix bad day of week in changelog (rpmbuild warning)
  + add dependency to rpm-build package instead rpmbuild binary
- Adjust patch rpmrebuild-fix-bashims.patch
- Pick new gpg block for rpmrebuild.keyring
- Spec cleanup
* Tue May  5 2015 mpluskal@suse.com
- Remove obsolete dependency on gpg-offline
- Cleanup spec file with spec-cleaner
* Sun Dec 28 2014 Led <ledest@gmail.com>
- fix bashisms in demofiles.sh script
- add patches:
  * rpmrebuild-fix-bashisms.patch
* Thu Dec  5 2013 bruno@ioda-net.ch
- Update to 2.11
  * Wed Nov 22 2013 <gerbier@users.sourceforge.net> 2.11
  - add install option
  * Sun Aug 11 2013 <gerbier@users.sourceforge.net> 2.10-2
  - bugfix from 2.10 on test install : test was inverted (applied on rpm files instead installed rpm)
  * Tue Aug 01 2013 <valery_reznic@users.sourceforge.net> 2.10
  - add tag DISTTAG (feature request)
  - do not test install if work on rpm files
  - applied patch from Olivier Bourdon for pretrans and postrans
- Packaging fix bnc#832338
  - Add Require rpm-build
* Tue Mar 12 2013 lazy.kent@opensuse.org
- Update to 2.9.
  * Fix to work with rpm 4.10 - error: incorrect format: invalid
    field width.
- Changes in 2.8.
  * Can handle SUGGESTS/ENHANCES rpm tag.
  * Add --cap-from-fs/cap-from-db options.
- Changes in 2.7.
  * Patch from Andreas Kainz for package file checking.
  * Add new unset_tag plugin.
  * Fix -l / --list-plugin option.
  * Add support of posix capability.
  * Add new un_prelink plugin.
  * Add RPMREBUILD_OPTS environment variable.
  * Fix problem with different architecture (build 32bit on
    64bits).
  * Fix bad arch on gpg-pubkey packages.
- Use full URL as a source.
- Verify GPG signature.
- Package docs.
- Mark man pages as doc.
* Thu Oct 13 2011 bruno@ioda-net.ch
- Update to version 2.6
- spec cleaner
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build-
* Tue Apr  6 2010 hvogel@novell.com
- Update to version 2.4
  o add -l / --list-plugin option
  o add -5 / --md5-compat-digest option
* Wed Aug  5 2009 hvogel@suse.de
- Update to version 2.3
  o fix installation test when repackaged rpm file (with -p)
  o fix for rpm 4.6 that ignore BuildRoot in the spec file flag
  o do not use popt any more
* Mon Sep  8 2008 hvogel@suse.de
- Update to version 2.2.3
  * fix a problem with new rpm security
  * fix a bug when working on package file with path
* Thu Apr  3 2008 hvogel@suse.de
- Update to version 2.2.1
  * fix bug on uid/gid with --pug-from-fs option
  * demo plugin : better error message
  * do not remove /etc/popt : it does not belong our package
  * add new set_tag plugin
  * new demofiles plugin
* Tue Dec 11 2007 hvogel@suse.de
- Initial Package, Version 2.2.0
